@@ -9,11 +9,11 @@ from scrobbles.models import Scrobble
 logger = logging.getLogger(__name__)
 
 
-def process_audioscrobbler_tsv_file(file_path, tz=None):
+def process_audioscrobbler_tsv_file(file_path, user_tz=None):
     """Takes a path to a file of TSV data and imports it as past scrobbles"""
     new_scrobbles = []
-    if not tz:
-        tz = pytz.utc
+    if not user_tz:
+        user_tz = pytz.utc
 
     with open(file_path) as infile:
         source = 'Audioscrobbler File'
@@ -71,8 +71,10 @@ def process_audioscrobbler_tsv_file(file_path, tz=None):
                 track.musicbrainz_id = row[7]
                 track.save()
 
-            timestamp = datetime.utcfromtimestamp(int(row[6])).replace(
-                tzinfo=tz
+            timestamp = (
+                datetime.utcfromtimestamp(int(row[6]))
+                .replace(tzinfo=user_tz)
+                .astimezone(pytz.utc)
             )
             source = 'Audioscrobbler File'
 
